=======
ctdproc
=======


.. image:: https://img.shields.io/pypi/v/ctdproc.svg
        :target: https://pypi.python.org/pypi/ctdproc

.. image:: https://img.shields.io/travis/gunnarvoet/ctdproc.svg
        :target: https://travis-ci.com/gunnarvoet/ctdproc

.. image:: https://readthedocs.org/projects/ctdproc/badge/?version=latest
        :target: https://ctdproc.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status



CTD data processing in python. 

* Free software: MIT license
* Documentation: https://ctdproc.readthedocs.io.


Features
--------

* Convert CTD data collected with Seabird 9/11 systems in hex-format to human-readable formats and physical units.

* Process CTD time series data into depth-binned profiles.

Credits
-------

This package borrows heavily from a toolbox written in MATLAB® with contributions from Jennifer MacKinnon, Shaun Johnston, Daniel Rudnick, Robert Todd and others.